<?php
/**
 * Définit l'administration du plugin Pensebetes
 *
 * Installation et désinstallation du plugin
 *
 * @plugin     Pensebetes
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Pensebetes\Administrations
 */

if (!defined('_ECRIRE_INC_VERSION')) return;

/**
 * Création et mise à jour du plugin Pensebetes
 *
 * @param  string $nom_meta_base_version version du schéma de données du plugin installé
 * @param  string $version_cible Version déclarée dans paquet.xml
 * @return void
**/

function pensebetes_upgrade($nom_meta_base_version, $version_cible){

	$maj = array();
	$maj['create'] = array(
		array('maj_tables', array('spip_pensebetes', 'spip_pensebetes_liens')),
		array('ecrire_config','pensebetes/mes_objets', array('spip_articles')),
		array('ecrire_config','pensebetes/mes_lieux', array('accueil')),
		array('ecrire_config','pensebetes/mes_boites', array('accueil','auteur')),
		array('ecrire_config','pensebetes/mes_statuts', array('0minirezo', '1comite'))
	);
	$maj['1.0.1'] = array(
		array('ecrire_config','pensebetes/mes_objets', array('article')),
		array('ecrire_config','pensebetes/mes_lieux', array('accueil')),
		array('ecrire_config','pensebetes/mes_boites', array('accueil','auteur')),
	);
	# récupéré et transformer les valeurs des anciennes configs
	$maj['1.0.2'] = array(
		array('cfg_mes_objets')
	);
	# ajouter des valeurs à la config
	$maj['1.0.3'] = array(
		array('ecrire_config','pensebetes/mes_statuts', array('0minirezo', '1comite'))
	);

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}

/**
 * Faire le ménage lors de la désinstallation du plugin Pensebetes
 *
 * @param  string $nom_meta_base_version version du schéma de données du plugin installé
 * @return void
**/

function pensebetes_vider_tables($nom_meta_base_version) {
	sql_drop_table("spip_pensebetes");
	sql_drop_table("spip_pensebetes_liens");
	effacer_config("pensebetes/mes_statuts");
	effacer_config("pensebetes/mes_objets");
	effacer_config("pensebetes/mes_lieux");
	effacer_config("pensebetes/mes_boites");
	effacer_config("pensebetes/espacepublic");
	effacer_meta($nom_meta_base_version);
}

/**
 * Fonction privée : remplacer les noms d'objet par les noms de table
 *
 * Permettre de conserver la configuration définie par les versions précédentes à la version 1.0.2
 *
 * @return void
 */
function cfg_mes_objets() {
	include_spip('inc/config'); // pour la fonction lire_config()
	$mes_objets = lire_config("pensebetes/mes_objets");
	if ($mes_objets) {
		foreach($mes_objets as $cle => &$valeur){
			$table = table_objet($objet);
			if ($table) {
				$valeur = 'spip_' . $table;
			}
		}
	}
	ecrire_config("pensebetes/mes_objets", $mes_objets);
	
}